<?php

/**
 * Plugin installer. This class is a container for install and uninstall code.
 * 
 * @author Lukasz Kujawa <lukasz.f24@gmail.com>
 * @category PostMiner
 */
class PostMiner_Installer
{
    
    /**
     * SQL statement for creating terms table
     * @var string
     */
    static private $SQL_TERMS = "CREATE TABLE IF NOT EXISTS `%s_terms` (
                                  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
                                  `value` varchar(32) NOT NULL,
                                  PRIMARY KEY (`id`),
                                  KEY `value` (`value`)
                                ) ENGINE=MyISAM AUTO_INCREMENT=1";
    
    
    /**
     * SQL statement for creating term_relationships table
     * @var string
     */
    static private $SQL_TERMS_RELATION = "CREATE TABLE IF NOT EXISTS `%s_term_relationships` (
                                  `object_id` bigint(20) unsigned NOT NULL,
                                  `postminer_term_id` int(10) unsigned NOT NULL,
                                  `weight` double NOT NULL,
                                  KEY `object_id` (`object_id`,`postminer_term_id`)
                                ) ENGINE=MyISAM";

    
    /**
     * SQL statement for dropping terms table
     * @var string 
     */
    static private $SQL_DROP_TERMS = "DROP TABLE `%s_terms`";
    
    /**
     * SQL statement for dropping terms relationship table
     * @var string
     */
    static private $SQL_DROP_TERMS_RELATION = "DROP TABLE `%s_term_relationships`";
    
    /**
     * Plugin installer. Creates tables and index all posts.
     *  
     * @return void
     */
    static function install()
    {
        require_once( POST_MINER__PATH . 'Indexer.php' );
        
        global $wpdb;
        
        $prefix = $wpdb->prefix . 'postminer';
        
        $wpdb->get_results( sprintf( self::$SQL_TERMS, $prefix ) );
        $wpdb->get_results( sprintf( self::$SQL_TERMS_RELATION, $prefix ) );
        
        add_option("post-miner_db_version", '1.0.0');
        
        add_option("post-miner_recommendations_header", "You might be also interested in:");
        
        add_option("post-miner_recommendations_limit", 5);
        
        PostMiner_Indexer::indexPosts();
        
    }
    
    /**
     * Plugin uninstaller.
     * 
     * @return void
     */
    static function uninstall()
    {
        global $wpdb;
        
        $prefix = $wpdb->prefix . 'postminer';
        
        $wpdb->get_results( sprintf( self::$SQL_DROP_TERMS, $prefix ) );
        $wpdb->get_results( sprintf( self::$SQL_DROP_TERMS_RELATION, $prefix ) );
        
        delete_option("post-miner_db_version");
        delete_option("post-miner_recommendations_header");
        delete_option("post-miner_recommendations_limit");
    }
}